#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-475ejTSjJdU3LVhFNxZo7A
key:                  lift-type-0.1.2.0-475ejTSjJdU3LVhFNxZo7A
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  3d878afeeccc411ea1c8b0f0e37d4de9
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-475ejTSjJdU3LVhFNxZo7A
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

